==> gameap-3.1-shared.zip: upload/resources/lang/en/games.php <==
<?php

return [
    'title_games_list'    => 'Games List',
    'title_game'          => 'Game',
    'title_game_mod'      => 'Game Mod',
    'title_add'           => 'Add Game',
    'title_add_mod'       => 'Add Game Mod',
    'title_edit'          => 'Edit Game',
    'title_edit_mod'      => 'Edit Game Mod',
    
    'game'                => 'Game',
    'games'               => 'Games',
    
    'add'                 => 'Add Game',
    'add_mod'             => 'Add Mod',
    'add_first_mod'       => 'Add first mod',

    'upgrade'             => 'Upgrade Games',
    
    'name'                => 'Name',
    'code'                => 'Code',
    'engine'              => 'Engine',
    'mods'                => 'Mods',
    
    'run_commands'        => 'Run Commands',
    
    // GameMod edit page
    'main'                => 'Main',
    'servers_commands'    => 'Game Servers Commands',
    'vars'                => 'Vars',
    'fast_rcon_commands'  => 'Fast RCON commands',
    
    'basic_info'          => 'Basic info',
    'game_info'           => 'Game info',
    'game_mod_info'       => 'Game mod info',
    'steam_info'          => 'Steamcmd settings',
    'repositories'        => 'Repositories',
    'repositories_local'  => 'Local repositories',
    'repositories_remote' => 'Remote repositories',
    
    // Descriptions
    'd_kick_cmd'          => 'Shortcodes: {id} -- player id, {name} -- player name',
    'd_ban_cmd'           => 'Shortcodes: {id} -- player id, {name} -- player name, {time} -- time, {reason}',
    'd_srestart_cmd'      => '',
    'd_chname_cmd'        => 'Shortcodes: {id} -- player id, {name} -- current player name, {new_name} -- new player name, {time} -- time, {reason}',
    'd_chmap_cmd'         => 'Shortcodes: {map}',
    'd_sendmsg_cmd'       => 'Shortcodes: {msg} -- message',
    'd_passwd_cmd'        => 'Shortcodes: {password} -- password',

    'd_upgrade_confirm'   => 'This action will upgrade games and game mods. Some of the data you have changed may be overwritten. Continue?',
    
    'var'                 => 'Var',
    'default'             => 'Default',
    'info'                => 'Info',
    'admin_var'           => 'Admin Var',
    
    'description'         => 'Description',
    'rcon_command'        => 'RCON Command',

    'create_success_msg' => 'Game created successfully',
    'update_success_msg' => 'Game updated successfully',
    'delete_success_msg' => 'Game deleted successfully',
    
    'mod_create_success_msg' => 'Game Modification created successfully',
    'mod_update_success_msg' => 'Game Modification updated successfully',
    'mod_delete_success_msg' => 'Game Modification deleted successfully',

    'upgrade_success_msg'    => 'Games upgraded sucessfully',
    'upgrade_fail_msg'       => 'Unable to upgrade Games',
];

==> gameap-3.2-shared.zip: upload/resources/lang/en/games.php <==
<?php

return [
    'title_games_list'    => 'Games List',
    'title_game'          => 'Game',
    'title_game_mod'      => 'Game Mod',
    'title_add'           => 'Add Game',
    'title_add_mod'       => 'Add Game Mod',
    'title_edit'          => 'Edit Game',
    'title_edit_mod'      => 'Edit Game Mod',
    
    'game'                => 'Game',
    'games'               => 'Games',
    
    'add'                 => 'Add Game',
    'add_mod'             => 'Add Mod',
    'add_first_mod'       => 'Add first mod',

    'upgrade'             => 'Upgrade Games',
    
    'name'                => 'Name',
    'code'                => 'Code',
    'engine'              => 'Engine',
    'mods'                => 'Mods',
    
    'run_commands'        => 'Run Commands',
    
    // GameMod edit page
    'main'                => 'Main',
    'servers_commands'    => 'Game Servers Commands',
    'vars'                => 'Vars',
    'fast_rcon_commands'  => 'Fast RCON commands',
    
    'basic_info'          => 'Basic info',
    'game_info'           => 'Game info',
    'game_mod_info'       => 'Game mod info',
    'steam_info'          => 'Steamcmd settings',
    'repositories'        => 'Repositories',
    'repositories_local'  => 'Local repositories',
    'repositories_remote' => 'Remote repositories',
    
    // Descriptions
    'd_kick_cmd'          => 'Shortcodes: {id} -- player id, {name} -- player name',
    'd_ban_cmd'           => 'Shortcodes: {id} -- player id, {name} -- player name, {time} -- time, {reason}',
    'd_srestart_cmd'      => '',
    'd_chname_cmd'        => 'Shortcodes: {id} -- player id, {name} -- current player name, {new_name} -- new player name, {time} -- time, {reason}',
    'd_chmap_cmd'         => 'Shortcodes: {map}',
    'd_sendmsg_cmd'       => 'Shortcodes: {msg} -- message',
    'd_passwd_cmd'        => 'Shortcodes: {password} -- password',

    'd_upgrade_confirm'   => 'This action will upgrade games and game mods. Some of the data you have changed may be overwritten. Continue?',
    
    'var'                 => 'Var',
    'default'             => 'Default',
    'info'                => 'Info',
    'admin_var'           => 'Admin Var',
    
    'description'         => 'Description',
    'rcon_command'        => 'RCON Command',

    'create_success_msg' => 'Game created successfully',
    'update_success_msg' => 'Game updated successfully',
    'delete_success_msg' => 'Game deleted successfully',
    
    'mod_create_success_msg' => 'Game Modification created successfully',
    'mod_update_success_msg' => 'Game Modification updated successfully',
    'mod_delete_success_msg' => 'Game Modification deleted successfully',

    'upgrade_success_msg'    => 'Games upgraded sucessfully',
    'upgrade_fail_msg'       => 'Unable to upgrade Games',

    'delete_game_confirm_msg' => 'Are you sure you want to delete the game?',
    'delete_mod_confirm_msg'  => 'Are you sure you want to delete the game modification?',
];
